@@ -11,7 +11,7 @@ except ImportError:
 try:
     callable
 except NameError:
-    callable = lambda a: hasattr(a, "__cal__")
+    callable = lambda a: hasattr(a, "__call__")
 
 import types
 import urllib
@@ -39,10 +39,9 @@ def process_iter(proc):
             return
         else:
             proc.wait()
-            err = proc.stderr.read()
-            if err or proc.returncode not in (0, None):
-                raise ProcessException(err)
-
+            if proc.returncode not in (0, None):
+                raise ProcessException(proc.stderr.read())
+            print >>sys.stderr, proc.stderr.read()
 
 def nopen(f, mode="rb"):
     r"""
@@ -123,12 +122,25 @@ def reader(fname, header=True, sep="\t"):
     if not isinstance(fname, basestring) and \
         isinstance(fname, types.GeneratorType):
             line_gen = fname
+    elif sep is None:
+        import re
+        def _line_gen(f, sep):
+            if sep is None:
+                for line in nopen(f):
+                    yield line.rstrip("\r\n").split()
+        line_gen = _line_gen(fname, sep)
     else:
-        dialect = csv.excel
-        dialect.delimiter = sep
-        line_gen = csv.reader(nopen(fname), dialect=dialect)
-
-    a_dict = dict
+        try:
+            dialect = csv.excel
+            dialect.delimiter = sep
+            line_gen = csv.reader(nopen(fname), dialect=dialect)
+        except TypeError: # sep is None or a regex.
+            import re
+            sep = re.compile(sep)
+            def _re_line_gen(f, sep):
+                for line in nopen(f):
+                    yield sep.split(line.rstrip("\r\n"))
+            line_gen = _re_line_gen(fname, sep)
 
     # they sent in a class or function that accepts the toks.
     if callable(header):
@@ -137,17 +149,16 @@ def reader(fname, header=True, sep="\t"):
 
         raise StopIteration
 
+    a_dict = dict
     # if header is 'ordered', then use an ordered dictionary.
     if header == "ordered":
-        from collections import OrderedDict
-        a_dict = OrderedDict
+        from collections import OrderedDict as a_dict
         header = True
 
     if header == True:
         header = line_gen.next()
         header[0] = header[0].lstrip("#")
 
-
     if header:
         for toks in line_gen:
             yield a_dict(izip(header, toks))
@@ -168,12 +179,10 @@ def is_newer_b(a, bfiles):
     atime = os.stat(a).st_mtime # modification time
     for b in bfiles:
         # a has been modified since
-        if atime > os.stat(b).st_mtime: 
+        if atime > os.stat(b).st_mtime:
             return False
     return True
 
-
-
 if __name__ == "__main__":
     import doctest
     doctest.testmod(optionflags=doctest.ELLIPSIS |\
